Changelog
=========

## main

[View commits](https://github.com/OmenApps/django-calendardate/compare/0.1.1...HEAD)

## 0.1.1

* Updated README to provide some basic instructions and a bit of data about the CalendarDate model.
